@@ -33,6 +33,9 @@ class MyWhatify:
     def __init__(cls):
         pass
 
+    #############################
+    ###    user management    ###
+    #############################
     @classmethod
     def authenticate(cls, username, password):
         cls.login(email=username, password=password)
@@ -53,9 +56,9 @@ class MyWhatify:
         with allure.step('get user ID for current user or for user: ' + str(email)):
             logging.info('get user ID for current user or for user: ' + str(email))
             if email:
-                # my_toolkit.UserManagement.li
+                # my_toolkit.UserManagement.get_user_list(email=email)
+                user_id = -1
                 raise Exception('Need to implement')
-                user_id = 1
             else:
                 user_id = cls.user_token.get_user_id()
 
@@ -265,8 +268,8 @@ class MyWhatify:
     ###        Gettrs         ###
     #############################
     @classmethod
-    def get_api_post(cls, url, api_key=None):
-        return APIRequestor().post(url=url, api_key=api_key)
+    def get_api_post(cls, url, user_token=None):
+        return APIRequestor().post(url=url, api_key=user_token)
 
     @classmethod
     def get_data_source(cls, data_name):
@@ -365,52 +368,73 @@ class MyWhatify:
             len1 = len(my_list)
         return my_list
 
-    # def get_task_result_Tom(cls):
-    #     #todo delete fun
-    #     cls.login(email=vars_global.Users.AUTO_QA007.get_email(),
-    #                password=vars_global.Users.AUTO_QA007.get_password())
-    #
-    #     task_id = 138637
-    #     task_id_older = 138630
-    #     jwt = cls.user_token.get_token()
-    #     cls.halClient = HalClient(host=conf_server['HAL_HOST'], port=conf_server['HAL_PORT'], use_https=True)
-    #     cls.report_client = ReportsClient(host=conf_server['REPORT_HOST'], port=conf_server['REPORT_PORT'])
-    #     for index in range(99):
-    #         try:
-    #             if index % 3:
-    #                 task_result = HalClient(host=conf_server['HAL_HOST'], port=conf_server['HAL_PORT'], use_https=True).get_task_result(jwt=jwt, task_id=task_id)
-    #             if index % 2:
-    #                 sensitivity_result = ReportsClient(host=conf_server['REPORT_HOST'], port=conf_server['REPORT_PORT']).get_model_sensitivity(jwt=jwt, ensemble_id=task_id)
-    #         except:
-    #             pass
-    #     print('dddd')
-
     #############################
     ###       Connector       ###
     #############################
 
     @classmethod
-    def ls_client(cls, user_token: str = None):
-        return my_toolkit.Connector.get_client_path(user_token=user_token)
+    def ls_client(cls, path: bool = False, user_token: str = None):
+        """
+        Lists the existing files on S3
+        Args:
+            user_token (Optional[str]): Explicit `user_token`, not required, if `MyWhatify.login()` was run prior
+            path (Optional[bool]): True to include all path in folder, False just the files
+        Returns:
+            List of the files in S3, empty list if not found or not exist any file
+        """
+        return my_toolkit.Connector.get_client_path(path, user_token=user_token)
 
     @classmethod
-    def get_credentials(cls, api_key: str = None, renew: bool = False):
-        return my_toolkit.Connector.get_credentials(user_token=api_key, renew=renew)
+    def get_credentials(cls, user_token: str = None, renew: bool = False):
+        """
+        get and set the user credentials in MyWhatify
+
+        Args:
+            user_token (Optional[str]): Explicit `user_token`, not required, if `MyWhatify.login()` was run prior
+            renew (Optional[bool]): if we need to renew the credentials in MyWhatify
+        Returns:
+            The user credentials
+        """
+        return my_toolkit.Connector.get_credentials(user_token=user_token, renew=renew)
 
     @classmethod
     def get_s3_path(cls, user_token: str = None):
+        """
+        get user S3 path
+        Args:
+            user_token (Optional[str]): Explicit `user_token`, not required, if `MyWhatify.login()` was run prior
+        Returns:
+            path to user directory in s3
+        """
         return my_toolkit.Connector.get_s3_path(user_token=user_token)
 
     @classmethod
     def read_to_pandas_df(cls, file_name: str, user_token: str = None, **kwargs):
+        """
+        read s3 to panda
+        Args:
+            file_name (str): the file name to read in the user bucket
+            user_token (Optional[str]): Explicit `user_token`, not required, if `MyWhatify.login()` was run prior
+        Returns:
+            panda var with the file
+        """
         return my_toolkit.Connector.read_to_pandas_df(file_name=file_name, user_token=user_token, **kwargs)
 
     @classmethod
-    def write_pandas_df_to_s3(cls, df, file_name: str, user_token: str = None, **kwargs):  # s3_client, bucket, path, df):
+    def write_pandas_df_to_s3(cls, df, file_name: str, user_token: str = None, **kwargs):
+        """
+        write panda to s3
+        Args:
+            df (panda): panda file to be written into s3
+            file_name (str): the file name to name the file in the user bucket
+            user_token (Optional[str]): Explicit `user_token`, not required, if `MyWhatify.login()` was run prior
+        Returns:
+            None
+        """
         return my_toolkit.Connector.write_pandas_df_to_s3(df=df, file_name=file_name, user_token=user_token, **kwargs)
 
     #############################
-    ###       data_file       ###
+    ###   old data_file       ###
     #############################
 
     @classmethod
@@ -450,3 +474,21 @@ class MyWhatify:
     ###      Validation       ###
     #############################
 
+    @classmethod
+    def test_myAPI(cls, var: str, user_token: str = None):
+        return my_toolkit.UserManagement.test_API(var_str=var, user_token=user_token)
+
+# """
+# Lists the existing Datasources - supports filtering, sorting and pagination.
+#
+# Args:
+#     search_term (Optional[str]): Return only records that contain the `search_term` in any field.
+#     page (Optional[int]): For pagination, which page to return.
+#     page_size (Optional[int]): For pagination, how many records will appear in a single page.
+#     sort (Optional[Dict[str, Union[str, int]]]): Dictionary of rules  to sort the results by.
+#     filter_ (Optional[Dict[str, Union[str, int]]]): Dictionary of rules to filter the results by.
+#     user_token (Optional[str]): Explicit `user_token`, not required, if `MyWhatify.login()` was run prior.
+#
+# Returns:
+#     WhatifyResponse: Datasources are represented as nested dictionaries under `hits`.
+# """
\ No newline at end of file
